@@ -241,7 +241,8 @@ sub execute_standard {
   make_path($output_dir) unless -d $output_dir;
 
   # Execute the child process
-  $self->boss->message(4, "execute_standard stdout='$out' stderr='$err'\n");
+  $self->boss->message(4, "execute_standard stdout='$out'\n") if $out;
+  $self->boss->message(4, "execute_standard stderr='$err'\n") if $err;
   $self->boss->message(4, "execute_standard cmd=".pp($cmd)."\n");
   my $exit_code;
   my $rv = IPC::Run3::run3($cmd, \undef, $out, $err);
@@ -256,7 +257,7 @@ sub execute_special {
   $env = {} unless $env;
   my %original_env = %ENV;
   local %ENV;
-  %ENV = (%original_env, %{$self->global->{build_ENV}}, %$env);
+  %ENV = (%original_env, %{$self->global->{build_ENV}}, %$env); #SPECIAL
 
   $self->boss->message(4, "execute_special PATH='$ENV{PATH}'\n");
 
@@ -264,7 +265,8 @@ sub execute_special {
   make_path($output_dir) unless -d $output_dir;
 
   # Execute the child process
-  $self->boss->message(4, "execute_special stdout='$out' stderr='$err'\n");
+  $self->boss->message(4, "execute_special stdout='$out'\n") if $out;
+  $self->boss->message(4, "execute_special stderr='$err'\n") if $err;
   $self->boss->message(6, "execute_special env=".pp(\%ENV)."\n");
   $self->boss->message(4, "execute_special cmd=".pp($cmd)."\n");
   my $exit_code;
@@ -425,10 +427,12 @@ sub _install_module {
       $env->{$var} = $self->boss->resolve_name($args{env}->{$var});
     }
   }
-  # resolve macros in module name
+  # resolve macros
+  $args{makefilepl_param} = $self->boss->resolve_name($args{makefilepl_param}) if defined $args{makefilepl_param};
+  $args{buildpl_param}    = $self->boss->resolve_name($args{buildpl_param})    if defined $args{buildpl_param};
   $args{module} = $self->boss->resolve_name($args{module});
   $args{module} =~ s|\\|/|g; # cpanm dislikes backslashes
-
+  
   my %params = ( '-url' => $self->global->{cpan_url}, '-install_to' => 'vendor', '-module' => $args{module} ); #XXX-TODO multiple modules?
   $params{'-out_dumper'}         = $dumper_file if $dumper_file;
   $params{'-out_nstore'}         = $nstore_file if $nstore_file;
@@ -441,6 +445,7 @@ sub _install_module {
   $params{'-interactivity'}      = $args{interactivity}      if defined $args{interactivity};
   $params{'-makefilepl_param'}   = $args{makefilepl_param}   if defined $args{makefilepl_param}; #XXX-TODO multiple args?
   $params{'-buildpl_param'}      = $args{buildpl_param}      if defined $args{buildpl_param};    #XXX-TODO multiple args?
+  
   # handle global test skip
   $params{'-skiptest'} = 1 unless $self->global->{test_modules};
   # Execute the module install script
